﻿using System;
using System.Collections.Generic;
using System.Linq;
using System.Text;
using System.Threading.Tasks;
using System.IO;
using System.IO.Compression;
using System.Net; 

namespace SimpleFileFetcher
{
    class Program
    {
        private static Uri targetUri;
        private static FileInfo targetFile;
        private static bool doUnzip = false;
        private static bool deleteFile = false;

        static void Main(string[] args)
        {
            try
            {
                // parse arguments
                ParseArgs(args);

                // make sure target location exists
                if (!Directory.Exists(targetFile.DirectoryName))
                    Directory.CreateDirectory(targetFile.DirectoryName);

                // download file
                using (WebClient Client = new WebClient())
                {
                    Client.DownloadFile(targetUri.AbsoluteUri, targetFile.FullName);
                }


                // optionally unzip it
                if (doUnzip)
                {
                    try
                    {
                        ZipFile.ExtractToDirectory(targetFile.FullName, targetFile.DirectoryName);
                    }
                    catch (System.IO.IOException ex)
                    {
                        if (ex.Message.Contains("already exists."))
                            Console.WriteLine("One or more extracted files already exist, skipped unzip");
                        else
                            throw; // else re-throw the trapped exception
                    }
                }

                //Decompress(targetFile);

                // optionally delete original file
                if (deleteFile)
                    File.Delete(targetFile.FullName);

            }
            catch (Exception ex)
            {
                Console.WriteLine("An error occured: " + ex.Message);
            }
        }

        static void ParseArgs(string[] args)
        {
            if (args.Length == 0)
            {
                System.Console.WriteLine("We need some arguments. Proper format is: -targeturi:<uri> -targetfile:<file name/path>");
                System.Console.WriteLine("Optional parameters include '-unzip' to decompress the target file after download and '-deleteoriginal' to remove the downloaded file");
                throw new ArgumentException("No Arguments Specified.");
            }

            foreach (string arg in args)
            {
                // scrub parameter
                string cleanArg = arg.Trim().ToLower();

                // save parameter values
                if (cleanArg.StartsWith("-targeturi:"))
                    targetUri = new Uri(arg.Substring(11)); // will throw exception if bad uri
                if (cleanArg.StartsWith("-targetfile:"))
                    targetFile = new FileInfo(arg.Substring(14));
                if (cleanArg.StartsWith("-unzip"))
                    doUnzip = true;
                if (cleanArg.StartsWith("-deleteoriginal"))
                    deleteFile = true;
            }
        }
    }
}
